@@ -39,32 +39,32 @@ class FileLink:
 
     @property
     def size(self) -> int:
-        warnings.warn("'size' is deprecated, replace it with 'file_info.size'", DeprecationWarning)
+        warnings.warn("is deprecated, replace it with 'file_info.size'", DeprecationWarning)
         return self.file_info.size
 
     @property
     def full_file_name(self) -> str:
-        warnings.warn("'full_file_name' is deprecated, replace it with 'filename'", DeprecationWarning)
+        warnings.warn("is deprecated, replace it with 'filename'", DeprecationWarning)
         return self.filename
 
     @property
     def file_extension(self) -> str | None:
-        warnings.warn("'file_extension' is deprecated, replace it with 'extension'", DeprecationWarning)
+        warnings.warn("is deprecated, replace it with 'extension'", DeprecationWarning)
         return self.extension
 
     @property
     def quoted_full_file_name(self) -> str:
-        warnings.warn("'quoted_full_file_name' is deprecated, was removed", DeprecationWarning)
+        warnings.warn("is deprecated, was removed", DeprecationWarning)
         return self.filename
 
     @property
     def content_type(self) -> str:
-        warnings.warn("'content_type' is deprecated, was removed", DeprecationWarning)
+        warnings.warn("is deprecated, was removed", DeprecationWarning)
         return ''
 
     @property
     def thumbnail(self) -> None:
-        warnings.warn("'thumbnail' is deprecated, was removed", DeprecationWarning)
+        warnings.warn("is deprecated, was removed", DeprecationWarning)
         return None
 
 
@@ -110,7 +110,7 @@ class FileServerConnector:
         return original, thumbnail
 
     async def add_file(self, file: bytes, filename: str, **kwargs) -> FileLink:
-        warnings.warn("'add_file' is deprecated, replace it with 'upload_file'", DeprecationWarning)
+        warnings.warn("is deprecated, replace it with 'upload_file'", DeprecationWarning)
         return (await self.upload_file(filename, file))[0]
 
     async def delete_file(self, file_id: str) -> FileLink:
